aboutsummaryrefslogtreecommitdiff
path: root/src/gr
diff options
context:
space:
mode:
authorjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2003-07-10 16:08:45 +0000
committerjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2003-07-10 16:08:45 +0000
commit4c225b249e899f8b5b2818fcb05e52a3d56f6933 (patch)
tree4b868957815f1ec82c43b1d06fefc2abfd147e80 /src/gr
parent6c5417c54493595480e29131e3b1267b101fa4f4 (diff)
add max_allowable_horizon_radius
parameter to (we think) fix a serious bug where if one horizon goes off the edge of the grid, we fail to find any other horizons git-svn-id: http://svn.einsteintoolkit.org/cactus/EinsteinAnalysis/AHFinderDirect/trunk@1130 f88db872-0e4f-0410-b76b-b9085cfa78c5
Diffstat (limited to 'src/gr')
-rw-r--r--src/gr/gr.hh12
-rw-r--r--src/gr/misc-gr.cc3
2 files changed, 11 insertions, 4 deletions
diff --git a/src/gr/misc-gr.cc b/src/gr/misc-gr.cc
index b17a7e9..9ca3d1f 100644
--- a/src/gr/misc-gr.cc
+++ b/src/gr/misc-gr.cc
@@ -127,6 +127,9 @@ case expansion_success:
case expansion_failure__surface_nonfinite:
return "infinity/NaN in surface shape!";
break;
+case expansion_failure__surface_too_large:
+ return "surface too large";
+ break;
case expansion_failure__surface_outside_grid:
return "surface outside grid";
break;
diff --git a/src/gr/gr.hh b/src/gr/gr.hh
index 11ab58e..599d704 100644
--- a/src/gr/gr.hh
+++ b/src/gr/gr.hh
@@ -32,10 +32,7 @@ enum Jacobian_compute_method
};
//
// this enum describes the status of an
// expansion()
// and/or
// expansion_Jacobian()
// computation which returns (i.e. which doesn't abort the Cactus run)
//
enum expansion_status
@@ -47,6 +44,13 @@ enum expansion_status
// non-finite() (i.e. +/-infinity or NaN) values found in h
expansion_failure__surface_nonfinite,
+ // surface is too large
+ // ... this value is never returned by expansion() or
+ // expansion_Jacobian() , but is placed in this enum
+ // for the convenience of higher-level software which
+ // wishes to have such an error condition
+ expansion_failure__surface_too_large,
+
// geometry interpolator returns CCTK_ERROR_INTERP_POINT_OUTSIDE
expansion_failure__surface_outside_grid,
@@ -32,10 +32,7 @@ enum Jacobian_compute_method
};
//
-// this enum describes the status of an
-// expansion()
-// and/or
-// expansion_Jacobian()
+// this enum describes the status of an expansion() or expansion_Jacobian()
// computation which returns (i.e. which doesn't abort the Cactus run)
//